@@ -7,13 +7,9 @@ Parameter usage / help text formatters
 
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Type, Callable, Iterator, Iterable, Tuple, Dict
 
-try:
-    from functools import cached_property
-except ImportError:
-    from ..compat import cached_property
-
 from ..config import SubcommandAliasHelpMode
 from ..context import ctx
 from ..core import get_config
