@@ -13,6 +13,8 @@ __all__ = ['InputType']
 
 
 class InputType(Generic[T], ABC):
+    __slots__ = ()
+
     @abstractmethod
     def __call__(self, value: str) -> T:
         """Process the parsed argument and convert it to the desired type"""
@@ -35,6 +37,6 @@ class InputType(Generic[T], ABC):
     def fix_default(self, value: Any) -> Optional[T]:
         return value
 
-    def format_metavar(self, choice_delim: str = ',') -> str:
+    def format_metavar(self, choice_delim: str = ',', sort_choices: bool = False) -> str:
         # TODO: Optional/required arg, or handle wrapping in []/{} in formatter
         return NotImplemented
